<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>EllipseDD</name>
    <message>
        <location filename="../EllipseDD.ui" line="+17"/>
        <location filename="../EllipseDDDialog.ui" line="+19"/>
        <source>X Diameter:</source>
        <translation>X直径:</translation>
    </message>
    <message>
        <location line="+23"/>
        <location filename="../EllipseDDDialog.ui" line="+80"/>
        <source>Y Diameter:</source>
        <translation>Y直径:</translation>
    </message>
    <message>
        <location line="+30"/>
        <location filename="../EllipseDDDialog.ui" line="-23"/>
        <source>Angle:</source>
        <translation>角度:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Reference Point:</source>
        <translation>基準点:</translation>
    </message>
    <message>
        <location filename="../EllipseDDInit.js" line="+2"/>
        <source>Ellipse with &amp;Diameters</source>
        <translation>直径指定の楕円</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Draw ellipse with position and diameters</source>
        <translation>位置と直径を指定して楕円を描く</translation>
    </message>
</context>
</TS>
